==> google-cloud-tpu-1.3.0.tar.gz: google-cloud-tpu-1.3.0/google/cloud/tpu/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.tpu_v1.services.tpu.client import TpuClient
from google.cloud.tpu_v1.services.tpu.async_client import TpuAsyncClient

from google.cloud.tpu_v1.types.cloud_tpu import AcceleratorType
from google.cloud.tpu_v1.types.cloud_tpu import CreateNodeRequest
from google.cloud.tpu_v1.types.cloud_tpu import DeleteNodeRequest
from google.cloud.tpu_v1.types.cloud_tpu import GetAcceleratorTypeRequest
from google.cloud.tpu_v1.types.cloud_tpu import GetNodeRequest
from google.cloud.tpu_v1.types.cloud_tpu import GetTensorFlowVersionRequest
from google.cloud.tpu_v1.types.cloud_tpu import ListAcceleratorTypesRequest
from google.cloud.tpu_v1.types.cloud_tpu import ListAcceleratorTypesResponse
from google.cloud.tpu_v1.types.cloud_tpu import ListNodesRequest
from google.cloud.tpu_v1.types.cloud_tpu import ListNodesResponse
from google.cloud.tpu_v1.types.cloud_tpu import ListTensorFlowVersionsRequest
from google.cloud.tpu_v1.types.cloud_tpu import ListTensorFlowVersionsResponse
from google.cloud.tpu_v1.types.cloud_tpu import NetworkEndpoint
from google.cloud.tpu_v1.types.cloud_tpu import Node
from google.cloud.tpu_v1.types.cloud_tpu import OperationMetadata
from google.cloud.tpu_v1.types.cloud_tpu import ReimageNodeRequest
from google.cloud.tpu_v1.types.cloud_tpu import SchedulingConfig
from google.cloud.tpu_v1.types.cloud_tpu import StartNodeRequest
from google.cloud.tpu_v1.types.cloud_tpu import StopNodeRequest
from google.cloud.tpu_v1.types.cloud_tpu import Symptom
from google.cloud.tpu_v1.types.cloud_tpu import TensorFlowVersion

__all__ = (
    "TpuClient",
    "TpuAsyncClient",
    "AcceleratorType",
    "CreateNodeRequest",
    "DeleteNodeRequest",
    "GetAcceleratorTypeRequest",
    "GetNodeRequest",
    "GetTensorFlowVersionRequest",
    "ListAcceleratorTypesRequest",
    "ListAcceleratorTypesResponse",
    "ListNodesRequest",
    "ListNodesResponse",
    "ListTensorFlowVersionsRequest",
    "ListTensorFlowVersionsResponse",
    "NetworkEndpoint",
    "Node",
    "OperationMetadata",
    "ReimageNodeRequest",
    "SchedulingConfig",
    "StartNodeRequest",
    "StopNodeRequest",
    "Symptom",
    "TensorFlowVersion",
)

==> google-cloud-tpu-1.3.4.tar.gz: google-cloud-tpu-1.3.4/google/cloud/tpu/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.tpu_v1.services.tpu.async_client import TpuAsyncClient
from google.cloud.tpu_v1.services.tpu.client import TpuClient
from google.cloud.tpu_v1.types.cloud_tpu import (
    AcceleratorType,
    CreateNodeRequest,
    DeleteNodeRequest,
    GetAcceleratorTypeRequest,
    GetNodeRequest,
    GetTensorFlowVersionRequest,
    ListAcceleratorTypesRequest,
    ListAcceleratorTypesResponse,
    ListNodesRequest,
    ListNodesResponse,
    ListTensorFlowVersionsRequest,
    ListTensorFlowVersionsResponse,
    NetworkEndpoint,
    Node,
    OperationMetadata,
    ReimageNodeRequest,
    SchedulingConfig,
    StartNodeRequest,
    StopNodeRequest,
    Symptom,
    TensorFlowVersion,
)

__all__ = (
    "TpuClient",
    "TpuAsyncClient",
    "AcceleratorType",
    "CreateNodeRequest",
    "DeleteNodeRequest",
    "GetAcceleratorTypeRequest",
    "GetNodeRequest",
    "GetTensorFlowVersionRequest",
    "ListAcceleratorTypesRequest",
    "ListAcceleratorTypesResponse",
    "ListNodesRequest",
    "ListNodesResponse",
    "ListTensorFlowVersionsRequest",
    "ListTensorFlowVersionsResponse",
    "NetworkEndpoint",
    "Node",
    "OperationMetadata",
    "ReimageNodeRequest",
    "SchedulingConfig",
    "StartNodeRequest",
    "StopNodeRequest",
    "Symptom",
    "TensorFlowVersion",
)
